@@ -13,7 +13,7 @@
 ** is not included in the SQLite library.  It is used for automated
 ** testing of the SQLite library.
 **
-** $Id: test3.c,v 1.12 2001/09/23 02:35:53 drh Exp $
+** $Id: test3.c,v 1.18 2002/08/11 20:10:48 drh Exp $
 */
 #include "sqliteInt.h"
 #include "pager.h"
@@ -67,12 +67,15 @@ static int btree_open(
        " FILENAME\"", 0);
     return TCL_ERROR;
   }
-  rc = sqliteBtreeOpen(argv[1], 0666, 10, &pBt);
+  rc = sqliteBtreeOpen(argv[1], 0666, 1000, &pBt);
   if( rc!=SQLITE_OK ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
   }
-  sprintf(zBuf,"0x%x",(int)pBt);
+  sprintf(zBuf,"%p", pBt);
+  if( strncmp(zBuf,"0x",2) ){
+    sprintf(zBuf, "0x%p", pBt);
+  }
   Tcl_AppendResult(interp, zBuf, 0);
   return TCL_OK;
 }
@@ -461,13 +464,13 @@ static int btree_pager_ref_dump(
 }
 
 /*
-** Usage:   btree_sanity_check ID ROOT ...
+** Usage:   btree_integrity_check ID ROOT ...
 **
 ** Look through every page of the given BTree file to verify correct
 ** formatting and linkage.  Return a line of text for each problem found.
 ** Return an empty string if everything worked.
 */
-static int btree_sanity_check(
+static int btree_integrity_check(
   void *NotUsed,
   Tcl_Interp *interp,    /* The TCL interpreter that invoked this command */
   int argc,              /* Number of arguments */
@@ -490,10 +493,10 @@ static int btree_sanity_check(
   for(i=0; i<argc-2; i++){
     if( Tcl_GetInt(interp, argv[i+2], &aRoot[i]) ) return TCL_ERROR;
   }
-  zResult = sqliteBtreeSanityCheck(pBt, aRoot, nRoot);
+  zResult = sqliteBtreeIntegrityCheck(pBt, aRoot, nRoot);
   if( zResult ){
     Tcl_AppendResult(interp, zResult, 0);
-    free(zResult); 
+    sqliteFree(zResult); 
   }
   return TCL_OK;
 }
@@ -589,6 +592,8 @@ static int btree_move_to(
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
   }
+  if( res<0 ) res = -1;
+  if( res>0 ) res = 1;
   sprintf(zBuf,"%d",res);
   Tcl_AppendResult(interp, zBuf, 0);
   return SQLITE_OK;
@@ -665,6 +670,8 @@ static int btree_next(
 ){
   BtCursor *pCur;
   int rc;
+  int res = 0;
+  char zBuf[100];
 
   if( argc!=2 ){
     Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
@@ -672,11 +679,45 @@ static int btree_next(
     return TCL_ERROR;
   }
   if( Tcl_GetInt(interp, argv[1], (int*)&pCur) ) return TCL_ERROR;
-  rc = sqliteBtreeNext(pCur, 0);
+  rc = sqliteBtreeNext(pCur, &res);
   if( rc ){
     Tcl_AppendResult(interp, errorName(rc), 0);
     return TCL_ERROR;
   }
+  sprintf(zBuf,"%d",res);
+  Tcl_AppendResult(interp, zBuf, 0);
+  return SQLITE_OK;
+}
+
+/*
+** Usage:   btree_first ID
+**
+** Move the cursor to the first entry in the table.
+*/
+static int btree_first(
+  void *NotUsed,
+  Tcl_Interp *interp,    /* The TCL interpreter that invoked this command */
+  int argc,              /* Number of arguments */
+  char **argv            /* Text of each argument */
+){
+  BtCursor *pCur;
+  int rc;
+  int res = 0;
+  char zBuf[100];
+
+  if( argc!=2 ){
+    Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
+       " ID\"", 0);
+    return TCL_ERROR;
+  }
+  if( Tcl_GetInt(interp, argv[1], (int*)&pCur) ) return TCL_ERROR;
+  rc = sqliteBtreeFirst(pCur, &res);
+  if( rc ){
+    Tcl_AppendResult(interp, errorName(rc), 0);
+    return TCL_ERROR;
+  }
+  sprintf(zBuf,"%d",res);
+  Tcl_AppendResult(interp, zBuf, 0);
   return SQLITE_OK;
 }
 
@@ -756,6 +797,35 @@ static int btree_data(
   return SQLITE_OK;
 }
 
+/*
+** Usage:   btree_payload_size ID
+**
+** Return the number of bytes of payload
+*/
+static int btree_payload_size(
+  void *NotUsed,
+  Tcl_Interp *interp,    /* The TCL interpreter that invoked this command */
+  int argc,              /* Number of arguments */
+  char **argv            /* Text of each argument */
+){
+  BtCursor *pCur;
+  int n1, n2;
+  char zBuf[50];
+
+  if( argc!=2 ){
+    Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
+       " ID\"", 0);
+    return TCL_ERROR;
+  }
+  if( Tcl_GetInt(interp, argv[1], (int*)&pCur) ) return TCL_ERROR;
+  sqliteBtreeKeySize(pCur, &n1);
+  sqliteBtreeDataSize(pCur, &n2);
+  sprintf(zBuf, "%d", n1+n2);
+  Tcl_AppendResult(interp, zBuf, 0);
+  free(zBuf);
+  return SQLITE_OK;
+}
+
 /*
 ** Usage:   btree_cursor_dump ID
 **
@@ -830,9 +900,13 @@ int Sqlitetest3_Init(Tcl_Interp *interp){
   Tcl_CreateCommand(interp, "btree_next", btree_next, 0, 0);
   Tcl_CreateCommand(interp, "btree_key", btree_key, 0, 0);
   Tcl_CreateCommand(interp, "btree_data", btree_data, 0, 0);
+  Tcl_CreateCommand(interp, "btree_payload_size", btree_payload_size, 0, 0);
+  Tcl_CreateCommand(interp, "btree_first", btree_first, 0, 0);
   Tcl_CreateCommand(interp, "btree_cursor_dump", btree_cursor_dump, 0, 0);
-  Tcl_CreateCommand(interp, "btree_sanity_check", btree_sanity_check, 0, 0);
+  Tcl_CreateCommand(interp, "btree_integrity_check", btree_integrity_check,0,0);
   Tcl_LinkVar(interp, "pager_refinfo_enable", (char*)&pager_refinfo_enable,
      TCL_LINK_INT);
+  Tcl_LinkVar(interp, "btree_native_byte_order",(char*)&btree_native_byte_order,
+     TCL_LINK_INT);
   return TCL_OK;
 }
