@@ -14,7 +14,7 @@
 ** This file contains functions for allocating memory, comparing
 ** strings, and stuff like that.
 **
-** $Id: util.c,v 1.29 2001/09/27 03:22:34 drh Exp $
+** $Id: util.c,v 1.50 2002/08/26 19:55:08 drh Exp $
 */
 #include "sqliteInt.h"
 #include <stdarg.h>
@@ -39,6 +39,9 @@ int sqlite_malloc_failed = 0;
 int sqlite_nMalloc;         /* Number of sqliteMalloc() calls */
 int sqlite_nFree;           /* Number of sqliteFree() calls */
 int sqlite_iMallocFail;     /* Fail sqliteMalloc() after this many calls */
+#if MEMORY_DEBUG>1
+static int memcnt = 0;
+#endif
 
 
 /*
@@ -49,11 +52,15 @@ void *sqliteMalloc_(int n, char *zFile, int line){
   void *p;
   int *pi;
   int k;
-  sqlite_nMalloc++;
   if( sqlite_iMallocFail>=0 ){
     sqlite_iMallocFail--;
     if( sqlite_iMallocFail==0 ){
       sqlite_malloc_failed++;
+#if MEMORY_DEBUG>1
+      fprintf(stderr,"**** failed to allocate %d bytes at %s:%d\n",
+              n, zFile,line);
+#endif
+      sqlite_iMallocFail--;
       return 0;
     }
   }
@@ -64,13 +71,15 @@ void *sqliteMalloc_(int n, char *zFile, int line){
     sqlite_malloc_failed++;
     return 0;
   }
+  sqlite_nMalloc++;
   pi[0] = 0xdead1122;
   pi[1] = n;
   pi[k+2] = 0xdead3344;
   p = &pi[2];
   memset(p, 0, n);
 #if MEMORY_DEBUG>1
-  fprintf(stderr,"malloc %d bytes at 0x%x from %s:%d\n", n, (int)p, zFile,line);
+  fprintf(stderr,"%06d malloc %d bytes at 0x%x from %s:%d\n",
+      ++memcnt, n, (int)p, zFile,line);
 #endif
   return p;
 }
@@ -96,7 +105,8 @@ void sqliteFree_(void *p, char *zFile, int line){
     }
     memset(pi, 0xff, (k+3)*sizeof(int));
 #if MEMORY_DEBUG>1
-    fprintf(stderr,"free %d bytes at 0x%x from %s:%d\n", n, (int)p, zFile,line);
+    fprintf(stderr,"%06d free %d bytes at 0x%x from %s:%d\n",
+         ++memcnt, n, (int)p, zFile,line);
 #endif
     free(pi);
   }
@@ -146,8 +156,8 @@ void *sqliteRealloc_(void *oldP, int n, char *zFile, int line){
   memset(oldPi, 0, (oldK+3)*sizeof(int));
   free(oldPi);
 #if MEMORY_DEBUG>1
-  fprintf(stderr,"realloc %d to %d bytes at 0x%x to 0x%x at %s:%d\n", oldN, n,
-    (int)oldP, (int)p, zFile, line);
+  fprintf(stderr,"%06d realloc %d to %d bytes at 0x%x to 0x%x at %s:%d\n",
+    ++memcnt, oldN, n, (int)oldP, (int)p, zFile, line);
 #endif
   return p;
 }
@@ -178,12 +188,16 @@ void sqliteStrRealloc(char **pz){
 ** Make a copy of a string in memory obtained from sqliteMalloc()
 */
 char *sqliteStrDup_(const char *z, char *zFile, int line){
-  char *zNew = sqliteMalloc_(strlen(z)+1, zFile, line);
+  char *zNew;
+  if( z==0 ) return 0;
+  zNew = sqliteMalloc_(strlen(z)+1, zFile, line);
   if( zNew ) strcpy(zNew, z);
   return zNew;
 }
 char *sqliteStrNDup_(const char *z, int n, char *zFile, int line){
-  char *zNew = sqliteMalloc_(n+1, zFile, line);
+  char *zNew;
+  if( z==0 ) return 0;
+  zNew = sqliteMalloc_(n+1, zFile, line);
   if( zNew ){
     memcpy(zNew, z, n);
     zNew[n] = 0;
@@ -227,6 +241,7 @@ void sqliteFree(void *p){
 ** works just like sqliteFree().
 */
 void *sqliteRealloc(void *p, int n){
+  void *p2;
   if( p==0 ){
     return sqliteMalloc(n);
   }
@@ -234,23 +249,27 @@ void *sqliteRealloc(void *p, int n){
     sqliteFree(p);
     return 0;
   }
-  p = realloc(p, n);
-  if( p==0 ){
+  p2 = realloc(p, n);
+  if( p2==0 ){
     sqlite_malloc_failed++;
   }
-  return p;
+  return p2;
 }
 
 /*
 ** Make a copy of a string in memory obtained from sqliteMalloc()
 */
 char *sqliteStrDup(const char *z){
-  char *zNew = sqliteMalloc(strlen(z)+1);
+  char *zNew;
+  if( z==0 ) return 0;
+  zNew = sqliteMalloc(strlen(z)+1);
   if( zNew ) strcpy(zNew, z);
   return zNew;
 }
 char *sqliteStrNDup(const char *z, int n){
-  char *zNew = sqliteMalloc(n+1);
+  char *zNew;
+  if( z==0 ) return 0;
+  zNew = sqliteMalloc(n+1);
   if( zNew ){
     memcpy(zNew, z, n);
     zNew[n] = 0;
@@ -280,7 +299,9 @@ void sqliteSetString(char **pz, const char *zFirst, ...){
   va_end(ap);
   sqliteFree(*pz);
   *pz = zResult = sqliteMalloc( nByte );
-  if( zResult==0 ) return;
+  if( zResult==0 ){
+    return;
+  }
   strcpy(zResult, zFirst);
   zResult += strlen(zResult);
   va_start(ap, zFirst);
@@ -341,13 +362,22 @@ void sqliteSetNString(char **pz, ...){
 ** the quote characters.  The conversion is done in-place.  If the
 ** input does not begin with a quote character, then this routine
 ** is a no-op.
+**
+** 2002-Feb-14: This routine is extended to remove MS-Access style
+** brackets from around identifers.  For example:  "[a-b-c]" becomes
+** "a-b-c".
 */
 void sqliteDequote(char *z){
   int quote;
   int i, j;
   if( z==0 ) return;
   quote = z[0];
-  if( quote!='\'' && quote!='"' ) return;
+  switch( quote ){
+    case '\'':  break;
+    case '"':   break;
+    case '[':   quote = ']';  break;
+    default:    return;
+  }
   for(i=1, j=0; z[i]; i++){
     if( z[i]==quote ){
       if( z[i+1]==quote ){
@@ -418,13 +448,19 @@ int sqliteStrNICmp(const char *zLeft, const char *zRight, int N){
   return N<0 ? 0 : *a - *b;
 }
 
-/* Notes on string comparisions.
+#if 0  /* NOT USED */
+/* 
+** The sortStrCmp() function below is used to order elements according
+** to the ORDER BY clause of a SELECT.  The sort order is a little different
+** from what one might expect.  This note attempts to describe what is
+** going on.
 **
 ** We want the main string comparision function used for sorting to
 ** sort both numbers and alphanumeric words into the correct sequence.
 ** The same routine should do both without prior knowledge of which
 ** type of text the input represents.  It should even work for strings
-** which are a mixture of text and numbers.
+** which are a mixture of text and numbers.  (It does not work for
+** numeric substrings in exponential notation, however.)
 **
 ** To accomplish this, we keep track of a state number while scanning
 ** the two strings.  The states are as follows:
@@ -517,9 +553,10 @@ static const unsigned char stateMachine[] = {
 };
 
 /* This routine does a comparison of two strings.  Case is used only
-** if useCase!=0.  Numbers compare in numerical order.
+** if useCase!=0.  Numeric substrings compare in numerical order for the
+** most part but this routine does not understand exponential notation.
 */
-static int privateStrCmp(const char *atext, const char *btext, int useCase){
+static int sortStrCmp(const char *atext, const char *btext, int useCase){
   register unsigned char *a, *b, *map, ca, cb;
   int result;
   register int cclass = 0;
@@ -537,6 +574,8 @@ static int privateStrCmp(const char *atext, const char *btext, int useCase){
       if( (ca=map[*a++])!=(cb=map[*b++]) ) break;
       cclass = stateMachine[cclass*N_CHAR_CLASS + charClass[ca]];
     }while( ca!=0 );
+    if( ca>='[' && ca<='`' ) cb = b[-1];
+    if( cb>='[' && cb<='`' ) ca = a[-1];
   }
   switch( cclass ){
     case 0:
@@ -589,163 +628,270 @@ static int privateStrCmp(const char *atext, const char *btext, int useCase){
   }
   return result;
 }
+#endif /* NOT USED */
 
 /*
-** Do a comparison of pure numerics.  If either string is not a pure
-** numeric, then return 0.  Otherwise return 1 and set *pResult to be
-** negative, zero or positive if the first string are numerially less than
-** equal to, or greater than the second.
+** Return TRUE if z is a pure numeric string.  Return FALSE if the
+** string contains any character which is not part of a number.
+**
+** Am empty string is considered numeric.
 */
-static int privateCompareNum(const char *a, const char *b, int *pResult){
-  char *endPtr;
-  double rA, rB;
-  int isNumA, isNumB;
-  if( isdigit(*a) || ((*a=='-' || *a=='+') && isdigit(a[1])) ){
-    rA = strtod(a, &endPtr);
-    isNumA = *endPtr==0;
-  }else{
-    isNumA = 0;
+static int sqliteIsNumber(const char *z){
+  if( *z=='-' || *z=='+' ) z++;
+  if( !isdigit(*z) ){
+    return *z==0;
   }
-  if( isdigit(*b) || ((*b=='-' || *b=='+') && isdigit(b[1])) ){
-    rB = strtod(b, &endPtr);
-    isNumB = *endPtr==0;
-  }else{
-    isNumB = 0;
+  z++;
+  while( isdigit(*z) ){ z++; }
+  if( *z=='.' ){
+    z++;
+    if( !isdigit(*z) ) return 0;
+    while( isdigit(*z) ){ z++; }
+    if( *z=='e' || *z=='E' ){
+      z++;
+      if( *z=='+' || *z=='-' ) z++;
+      if( !isdigit(*z) ) return 0;
+      while( isdigit(*z) ){ z++; }
+    }
   }
-  if( isNumB==0 && isNumA==0 ) return 0;
-  if( isNumA!=isNumB ){
-    *pResult =  isNumA - isNumB;
-  }else if( rA<rB ){
-    *pResult = -1;
-  }else if( rA>rB ){
-    *pResult = 1;
-  }else{
-    *pResult = 0;
-  }
-  return 1;
+  return *z==0;
 }
 
 /* This comparison routine is what we use for comparison operations
-** in an SQL expression.  (Ex:  name<'Hello' or value<5).  Compare two
-** strings.  Use case only as a tie-breaker.  Numbers compare in
-** numerical order.
+** between numeric values in an SQL expression.  "Numeric" is a little
+** bit misleading here.  What we mean is that the strings have a
+** type of "numeric" from the point of view of SQL.  The strings
+** do not necessarily contain numbers.  They could contain text.
+**
+** If the input strings both look like actual numbers then they
+** compare in numerical order.  Numerical strings are always less 
+** than non-numeric strings so if one input string looks like a
+** number and the other does not, then the one that looks like
+** a number is the smaller.  Non-numeric strings compare in 
+** lexigraphical order (the same order as strcmp()).
 */
 int sqliteCompare(const char *atext, const char *btext){
   int result;
-  if( !privateCompareNum(atext, btext, &result) || result==0 ){
-    result = privateStrCmp(atext, btext, 0);
-    if( result==0 ) result = privateStrCmp(atext, btext, 1);
+  int isNumA, isNumB;
+  if( atext==0 ){
+    return -1;
+  }else if( btext==0 ){
+    return 1;
   }
-  return result;
-}
-
-/*
-** If you compile just this one file with the -DTEST_COMPARE=1 option,
-** it generates a program to test the comparisons routines.  
-*/
-#ifdef TEST_COMPARE
-#include <stdlib.h>
-#include <stdio.h>
-int sortCmp(const char **a, const char **b){
-  return sqliteCompare(*a, *b);
-}
-int main(int argc, char **argv){
-  int i, j, k, n, cnt;
-  static char *azStr[] = {
-     "abc", "aBc", "abcd", "aBcd", 
-     "123", "124", "1234", "-123", "-124", "-1234", "+124",
-     "123.45", "123.456", "123.46", "-123.45", "-123.46", "-123.456", 
-     "x9", "x10", "x-9", "x-10", "X9", "X10",
-     "1.234e+02", "+123", "1.23E2", "1.2345e+2", "-1.2345e2", "+w"
-  };
-  n = sizeof(azStr)/sizeof(azStr[0]);
-  qsort(azStr, n, sizeof(azStr[0]), sortCmp);
-  for(i=0; i<n; i++){
-    printf("%s\n", azStr[i]);
-  }
-  printf("Sanity1...");
-  fflush(stdout);
-  cnt = 0;
-  for(i=0; i<n-1; i++){
-    char *a = azStr[i];
-    for(j=i+1; j<n; j++){
-      char *b = azStr[j];
-      if( sqliteCompare(a,b) != -sqliteCompare(b,a) ){
-        printf("Failed!  \"%s\" vs \"%s\"\n", a, b);
-        i = j = n;
-      }
-      cnt++;
-    }
-  }
-  if( i<n ){
-    printf(" OK (%d)\n", cnt);
-  }
-  printf("Sanity2...");
-  fflush(stdout);
-  cnt = 0;
-  for(i=0; i<n; i++){
-    char *a = azStr[i];
-    for(j=0; j<n; j++){
-      char *b = azStr[j];
-      for(k=0; k<n; k++){
-        char *c = azStr[k];
-        int x1, x2, x3, success;
-        x1 = sqliteCompare(a,b);
-        x2 = sqliteCompare(b,c);
-        x3 = sqliteCompare(a,c);
-        if( x1==0 ){
-          success = x2==x3;
-        }else if( x1<0 ){
-          success = (x2<=0 && x3<=0) || x2>0;
-        }else{
-          success = (x2>=0 && x3>=0) || x2<0;
-        }
-        if( !success ){
-          printf("Failed!  \"%s\" vs \"%s\" vs \"%s\"\n", a, b, c);
-          i = j = k = n+1;
-        }
-        cnt++;
+  isNumA = sqliteIsNumber(atext);
+  isNumB = sqliteIsNumber(btext);
+  if( isNumA ){
+    if( !isNumB ){
+      result = -1;
+    }else{
+      double rA, rB;
+      rA = atof(atext);
+      rB = atof(btext);
+      if( rA<rB ){
+        result = -1;
+      }else if( rA>rB ){
+        result = +1;
+      }else{
+        result = 0;
       }
     }
+  }else if( isNumB ){
+    result = +1;
+  }else {
+    result = strcmp(atext, btext);
   }
-  if( i<n+1 ){
-    printf(" OK (%d)\n", cnt);
-  }
-  return 0;
+  return result; 
 }
-#endif
 
 /*
 ** This routine is used for sorting.  Each key is a list of one or more
-** null-terminated strings.  The list is terminated by two nulls in
-** a row.  For example, the following text is key with three strings:
+** null-terminated elements.  The list is terminated by two nulls in
+** a row.  For example, the following text is a key with three elements
 **
-**            +one\000-two\000+three\000\000
+**            Aone\000Dtwo\000Athree\000\000
 **
-** Both arguments will have the same number of strings.  This routine
+** All elements begin with one of the characters "+-AD" and end with "\000"
+** with zero or more text elements in between.  Except, NULL elements
+** consist of the special two-character sequence "N\000".
+**
+** Both arguments will have the same number of elements.  This routine
 ** returns negative, zero, or positive if the first argument is less
 ** than, equal to, or greater than the first.  (Result is a-b).
 **
-** Every string begins with either a "+" or "-" character.  If the
-** character is "-" then the return value is negated.  This is done
-** to implement a sort in descending order.
+** Each element begins with one of the characters "+", "-", "A", "D".
+** This character determines the sort order and collating sequence:
+**
+**     +      Sort numerically in ascending order
+**     -      Sort numerically in descending order
+**     A      Sort as strings in ascending order
+**     D      Sort as strings in descending order.
+**
+** For the "+" and "-" sorting, pure numeric strings (strings for which the
+** isNum() function above returns TRUE) always compare less than strings
+** that are not pure numerics.  Non-numeric strings compare in memcmp()
+** order.  This is the same sort order as the sqliteCompare() function
+** above generates.
+**
+** The last point is a change from version 2.6.3 to version 2.7.0.  In
+** version 2.6.3 and earlier, substrings of digits compare in numerical 
+** and case was used only to break a tie.
+**
+** Elements that begin with 'A' or 'D' compare in memcmp() order regardless
+** of whether or not they look like a number.
+**
+** Note that the sort order imposed by the rules above is the same
+** from the ordering defined by the "<", "<=", ">", and ">=" operators
+** of expressions and for indices.  This was not the case for version
+** 2.6.3 and earlier.
 */
 int sqliteSortCompare(const char *a, const char *b){
   int len;
   int res = 0;
+  int isNumA, isNumB;
+  int dir;
 
   while( res==0 && *a && *b ){
-    res = sqliteCompare(&a[1], &b[1]);
-    if( res==0 ){
-      len = strlen(a) + 1;
-      a += len;
-      b += len;
+    if( a[0]=='N' || b[0]=='N' ){
+      if( a[0]==b[0] ){
+        a += 2;
+        b += 2;
+        continue;
+      }
+      if( a[0]=='N' ){
+        dir = b[0];
+        res = -1;
+      }else{
+        dir = a[0];
+        res = +1;
+      }
+      break;
     }
+    assert( a[0]==b[0] );
+    if( (dir=a[0])=='A' || a[0]=='D' ){
+      res = strcmp(&a[1],&b[1]);
+      if( res ) break;
+    }else{
+      isNumA = sqliteIsNumber(&a[1]);
+      isNumB = sqliteIsNumber(&b[1]);
+      if( isNumA ){
+        double rA, rB;
+        if( !isNumB ){
+          res = -1;
+          break;
+        }
+        rA = atof(&a[1]);
+        rB = atof(&b[1]);
+        if( rA<rB ){
+          res = -1;
+          break;
+        }
+        if( rA>rB ){
+          res = +1;
+          break;
+        }
+      }else if( isNumB ){
+        res = +1;
+        break;
+      }else{
+        res = strcmp(&a[1],&b[1]);
+        if( res ) break;
+      }
+    }
+    len = strlen(&a[1]) + 2;
+    a += len;
+    b += len;
   }
-  if( *a=='-' ) res = -res;
+  if( dir=='-' || dir=='D' ) res = -res;
   return res;
 }
 
+/*
+** Some powers of 64.  These constants are needed in the
+** sqliteRealToSortable() routine below.
+*/
+#define _64e3  (64.0 * 64.0 * 64.0)
+#define _64e4  (64.0 * 64.0 * 64.0 * 64.0)
+#define _64e15 (_64e3 * _64e4 * _64e4 * _64e4)
+#define _64e16 (_64e4 * _64e4 * _64e4 * _64e4)
+#define _64e63 (_64e15 * _64e16 * _64e16 * _64e16)
+#define _64e64 (_64e16 * _64e16 * _64e16 * _64e16)
+
+/*
+** The following procedure converts a double-precision floating point
+** number into a string.  The resulting string has the property that
+** two such strings comparied using strcmp() or memcmp() will give the
+** same results as a numeric comparison of the original floating point
+** numbers.
+**
+** This routine is used to generate database keys from floating point
+** numbers such that the keys sort in the same order as the original
+** floating point numbers even though the keys are compared using
+** memcmp().
+**
+** The calling function should have allocated at least 14 characters
+** of space for the buffer z[].
+*/
+void sqliteRealToSortable(double r, char *z){
+  int neg;
+  int exp;
+  int cnt = 0;
+
+  /* This array maps integers between 0 and 63 into base-64 digits.
+  ** The digits must be chosen such at their ASCII codes are increasing.
+  ** This means we can not use the traditional base-64 digit set. */
+  static const char zDigit[] = 
+     "0123456789"
+     "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+     "abcdefghijklmnopqrstuvwxyz"
+     "|~";
+  if( r<0.0 ){
+    neg = 1;
+    r = -r;
+    *z++ = '-';
+  } else {
+    neg = 0;
+    *z++ = '0';
+  }
+  exp = 0;
+
+  if( r==0.0 ){
+    exp = -1024;
+  }else if( r<(0.5/64.0) ){
+    while( r < 0.5/_64e64 && exp > -961  ){ r *= _64e64;  exp -= 64; }
+    while( r < 0.5/_64e16 && exp > -1009 ){ r *= _64e16;  exp -= 16; }
+    while( r < 0.5/_64e4  && exp > -1021 ){ r *= _64e4;   exp -= 4; }
+    while( r < 0.5/64.0   && exp > -1024 ){ r *= 64.0;    exp -= 1; }
+  }else if( r>=0.5 ){
+    while( r >= 0.5*_64e63 && exp < 960  ){ r *= 1.0/_64e64; exp += 64; }
+    while( r >= 0.5*_64e15 && exp < 1008 ){ r *= 1.0/_64e16; exp += 16; }
+    while( r >= 0.5*_64e3  && exp < 1020 ){ r *= 1.0/_64e4;  exp += 4; }
+    while( r >= 0.5        && exp < 1023 ){ r *= 1.0/64.0;   exp += 1; }
+  }
+  if( neg ){
+    exp = -exp;
+    r = -r;
+  }
+  exp += 1024;
+  r += 0.5;
+  if( exp<0 ) return;
+  if( exp>=2048 || r>=1.0 ){
+    strcpy(z, "~~~~~~~~~~~~");
+    return;
+  }
+  *z++ = zDigit[(exp>>6)&0x3f];
+  *z++ = zDigit[exp & 0x3f];
+  while( r>0.0 && cnt<10 ){
+    int digit;
+    r *= 64.0;
+    digit = (int)r;
+    assert( digit>=0 && digit<64 );
+    *z++ = zDigit[digit & 0x3f];
+    r -= digit;
+    cnt++;
+  }
+  *z = 0;
+}
+
 #ifdef SQLITE_UTF8
 /*
 ** X is a pointer to the first byte of a UTF-8 character.  Increment
@@ -962,33 +1108,57 @@ sqliteLikeCompare(const unsigned char *zPattern, const unsigned char *zString){
 }
 
 /*
-** Return a static string that describes the kind of error specified in the
-** argument.
+** Change the sqlite.magic from SQLITE_MAGIC_OPEN to SQLITE_MAGIC_BUSY.
+** Return an error (non-zero) if the magic was not SQLITE_MAGIC_OPEN
+** when this routine is called.
+**
+** This routine is a attempt to detect if two threads use the
+** same sqlite* pointer at the same time.  There is a race 
+** condition so it is possible that the error is not detected.
+** But usually the problem will be seen.  The result will be an
+** error which can be used to debug the application that is
+** using SQLite incorrectly.
 */
-const char *sqliteErrStr(int rc){
-  const char *z;
-  switch( rc ){
-    case SQLITE_OK:         z = "not an error";                          break;
-    case SQLITE_ERROR:      z = "SQL logic error or missing database";   break;
-    case SQLITE_INTERNAL:   z = "internal SQLite implementation flaw";   break;
-    case SQLITE_PERM:       z = "access permission denied";              break;
-    case SQLITE_ABORT:      z = "callback requested query abort";        break;
-    case SQLITE_BUSY:       z = "database is locked";                    break;
-    case SQLITE_LOCKED:     z = "database table is locked";              break;
-    case SQLITE_NOMEM:      z = "out of memory";                         break;
-    case SQLITE_READONLY:   z = "attempt to write a readonly database";  break;
-    case SQLITE_INTERRUPT:  z = "interrupted";                           break;
-    case SQLITE_IOERR:      z = "disk I/O error";                        break;
-    case SQLITE_CORRUPT:    z = "database disk image is malformed";      break;
-    case SQLITE_NOTFOUND:   z = "table or record not found";             break;
-    case SQLITE_FULL:       z = "database is full";                      break;
-    case SQLITE_CANTOPEN:   z = "unable to open database file";          break;
-    case SQLITE_PROTOCOL:   z = "database locking protocol failure";     break;
-    case SQLITE_EMPTY:      z = "table contains no data";                break;
-    case SQLITE_SCHEMA:     z = "database schema has changed";           break;
-    case SQLITE_TOOBIG:     z = "too much data for one table row";       break;
-    case SQLITE_CONSTRAINT: z = "constraint failed";                     break;
-    default:                z = "unknown error";                         break;
+int sqliteSafetyOn(sqlite *db){
+  if( db->magic==SQLITE_MAGIC_OPEN ){
+    db->magic = SQLITE_MAGIC_BUSY;
+    return 0;
+  }else{
+    db->magic = SQLITE_MAGIC_ERROR;
+    db->flags |= SQLITE_Interrupt;
+    return 1;
   }
-  return z;
+}
+
+/*
+** Change the magic from SQLITE_MAGIC_BUSY to SQLITE_MAGIC_OPEN.
+** Return an error (non-zero) if the magic was not SQLITE_MAGIC_BUSY
+** when this routine is called.
+*/
+int sqliteSafetyOff(sqlite *db){
+  if( db->magic==SQLITE_MAGIC_BUSY ){
+    db->magic = SQLITE_MAGIC_OPEN;
+    return 0;
+  }else{
+    db->magic = SQLITE_MAGIC_ERROR;
+    db->flags |= SQLITE_Interrupt;
+    return 1;
+  }
+}
+
+/*
+** Check to make sure we are not currently executing an sqlite_exec().
+** If we are currently in an sqlite_exec(), return true and set
+** sqlite.magic to SQLITE_MAGIC_ERROR.  This will cause a complete
+** shutdown of the database.
+**
+** This routine is used to try to detect when API routines are called
+** at the wrong time or in the wrong sequence.
+*/
+int sqliteSafetyCheck(sqlite *db){
+  if( db->recursionDepth ){
+    db->magic = SQLITE_MAGIC_ERROR;
+    return 1;
+  }
+  return 0;
 }
