@@ -1,7 +1,7 @@
 #
 # Run this Tcl script to generate the sqlite.html file.
 #
-set rcsid {$Id: c_interface.tcl,v 1.17 2001/10/12 17:30:05 drh Exp $}
+set rcsid {$Id: c_interface.tcl,v 1.35 2002/08/24 18:24:57 drh Exp $}
 
 puts {<html>
 <head>
@@ -12,7 +12,7 @@ puts {<html>
 The C language interface to the SQLite library
 </h1>}
 puts "<p align=center>
-(This page was last modified on [lrange $rcsid 3 4] GMT)
+(This page was last modified on [lrange $rcsid 3 4] UTC)
 </p>"
 
 puts {
@@ -20,7 +20,7 @@ puts {
 a C or C++ program.  This document gives an overview of the C/C++
 programming interface.</p>
 
-<h2>The API</h2>
+<h2>The Core API</h2>
 
 <p>The interface to the SQLite library consists of three core functions,
 one opaque data structure, and some constants used as return values.
@@ -28,6 +28,7 @@ The core interface is as follows:</p>
 
 <blockquote><pre>
 typedef struct sqlite sqlite;
+#define SQLITE_OK           0   /* Successful result */
 
 sqlite *sqlite_open(const char *dbname, int mode, char **errmsg);
 
@@ -40,101 +41,14 @@ int sqlite_exec(
   void*,
   char **errmsg
 );
-
-#define SQLITE_OK           0   /* Successful result */
-#define SQLITE_ERROR        1   /* SQL error or missing database */
-#define SQLITE_INTERNAL     2   /* An internal logic error in SQLite */
-#define SQLITE_PERM         3   /* Access permission denied */
-#define SQLITE_ABORT        4   /* Callback routine requested an abort */
-#define SQLITE_BUSY         5   /* The database file is locked */
-#define SQLITE_LOCKED       6   /* A table in the database is locked */
-#define SQLITE_NOMEM        7   /* A malloc() failed */
-#define SQLITE_READONLY     8   /* Attempt to write a readonly database */
-#define SQLITE_INTERRUPT    9   /* Operation terminated by sqlite_interrupt() */
-#define SQLITE_IOERR       10   /* Some kind of disk I/O error occurred */
-#define SQLITE_CORRUPT     11   /* The database disk image is malformed */
-#define SQLITE_NOTFOUND    12   /* (Internal Only) Table or record not found */
-#define SQLITE_FULL        13   /* Insertion failed because database is full */
-#define SQLITE_CANTOPEN    14   /* Unable to open the database file */
-#define SQLITE_PROTOCOL    15   /* Database lock protocol error */
-#define SQLITE_EMPTY       16   /* (Internal Only) Database table is empty */
-#define SQLITE_SCHEMA      17   /* The database schema changed */
-#define SQLITE_TOOBIG      18   /* Too much data for one row of a table */
-#define SQLITE_CONSTRAINT  19   /* Abort due to contraint violation */
 </pre></blockquote>
 
-<p>Only the three core routines shown above are required to use
-SQLite.  But there are many other functions that provide 
-useful interfaces.  These extended routines are as follows:
+<p>
+The above is all you really need to know in order to use SQLite
+in your C or C++ programs.  There are other convenience functions
+available (and described below) but we will begin by describing
+the core functions shown above.
 </p>
-
-<blockquote><pre>
-int sqlite_get_table(
-  sqlite*,
-  char *sql,
-  char ***result,
-  int *nrow,
-  int *ncolumn,
-  char **errmsg
-);
-
-void sqlite_free_table(char**);
-
-void sqlite_interrupt(sqlite*);
-
-int sqlite_complete(const char *sql);
-
-void sqlite_busy_handler(sqlite*, int (*)(void*,const char*,int), void*);
-
-void sqlite_busy_timeout(sqlite*, int ms);
-
-const char sqlite_version[];
-
-const char sqlite_encoding[];
-
-int sqlite_exec_printf(
-  sqlite*,
-  char *sql,
-  int (*)(void*,int,char**,char**),
-  void*,
-  char **errmsg,
-  ...
-);
-
-int sqlite_exec_vprintf(
-  sqlite*,
-  char *sql,
-  int (*)(void*,int,char**,char**),
-  void*,
-  char **errmsg,
-  va_list
-);
-
-int sqlite_get_table_printf(
-  sqlite*,
-  char *sql,
-  char ***result,
-  int *nrow,
-  int *ncolumn,
-  char **errmsg,
-  ...
-);
-
-int sqlite_get_table_vprintf(
-  sqlite*,
-  char *sql,
-  char ***result,
-  int *nrow,
-  int *ncolumn,
-  char **errmsg,
-  va_list
-);
-
-</pre></blockquote>
-
-<p>All of the above definitions are included in the "sqlite.h"
-header file that comes in the source tree.</p>
-
 <h2>Opening a database</h2>
 
 <p>Use the <b>sqlite_open()</b> function to open an existing SQLite
@@ -210,7 +124,7 @@ int Callback(void *pArg, int argc, char **argv, char **columnNames){
 <p>The first argument to the callback is just a copy of the fourth argument
 to <b>sqlite_exec()</b>  This parameter can be used to pass arbitrary
 information through to the callback function from client code.
-The second argument is the number columns in the query result.
+The second argument is the number of columns in the query result.
 The third argument is an array of pointers to strings where each string
 is a single column of the result for that record.  Note that the
 callback function reports a NULL value in the database as a NULL pointer,
@@ -225,13 +139,59 @@ argv[i] == 0
 </pre></blockquote>
 <p>The names of the columns are contained in the fourth argument.</p>
 
+<p>If the EMPTY_RESULT_CALLBACKS pragma is set to ON and the result of
+a query is an empty set, then the callback is invoked once with the
+third parameter (argv) set to 0.  In other words
+<blockquote><pre>
+argv == 0
+</pre></blockquote>
+The second parameter (argc)
+and the fourth parameter (columnNames) are still valid
+and can be used to determine the number and names of the result
+columns if there had been a result.
+The default behavior is not to invoke the callback at all if the
+result set is empty.</p>
+
 <p>The callback function should normally return 0.  If the callback
 function returns non-zero, the query is immediately aborted and 
 <b>sqlite_exec()</b> will return SQLITE_ABORT.</p>
 
-<p>The <b>sqlite_exec()</b> function returns an integer to indicate
-success or failure of the operation.  The following are possible
-return values:</p>
+<h2>Error Codes</h2>
+
+<p>
+The <b>sqlite_exec()</b> function normally returns SQLITE_OK.  But
+if something goes wrong it can return a different value to indicate
+the type of error.  Here is a complete list of the return codes:
+</p>
+
+<blockquote><pre>
+#define SQLITE_OK           0   /* Successful result */
+#define SQLITE_ERROR        1   /* SQL error or missing database */
+#define SQLITE_INTERNAL     2   /* An internal logic error in SQLite */
+#define SQLITE_PERM         3   /* Access permission denied */
+#define SQLITE_ABORT        4   /* Callback routine requested an abort */
+#define SQLITE_BUSY         5   /* The database file is locked */
+#define SQLITE_LOCKED       6   /* A table in the database is locked */
+#define SQLITE_NOMEM        7   /* A malloc() failed */
+#define SQLITE_READONLY     8   /* Attempt to write a readonly database */
+#define SQLITE_INTERRUPT    9   /* Operation terminated by sqlite_interrupt() */
+#define SQLITE_IOERR       10   /* Some kind of disk I/O error occurred */
+#define SQLITE_CORRUPT     11   /* The database disk image is malformed */
+#define SQLITE_NOTFOUND    12   /* (Internal Only) Table or record not found */
+#define SQLITE_FULL        13   /* Insertion failed because database is full */
+#define SQLITE_CANTOPEN    14   /* Unable to open the database file */
+#define SQLITE_PROTOCOL    15   /* Database lock protocol error */
+#define SQLITE_EMPTY       16   /* (Internal Only) Database table is empty */
+#define SQLITE_SCHEMA      17   /* The database schema changed */
+#define SQLITE_TOOBIG      18   /* Too much data for one row of a table */
+#define SQLITE_CONSTRAINT  19   /* Abort due to contraint violation */
+#define SQLITE_MISMATCH    20   /* Data type mismatch */
+#define SQLITE_MISUSE      21   /* Library used incorrectly */
+</pre></blockquote>
+
+<p>
+The meanings of these various return values are as follows:
+</p>
 
 <blockquote>
 <dl>
@@ -269,7 +229,7 @@ that the database is locked.  But the source of the lock is a recursive
 call to <b>sqlite_exec()</b>.  This return can only occur if you attempt
 to invoke sqlite_exec() from within a callback routine of a query
 from a prior invocation of sqlite_exec().  Recursive calls to
-sqlite_exec() are allowed as long as no more they all read-only or do
+sqlite_exec() are allowed as long as they do
 not attempt to write the same table.
 </p></dd>
 <dt>SQLITE_NOMEM</dt>
@@ -321,22 +281,151 @@ schema.  This is the return code for such cases.  Retrying the
 command usually will clear the problem.
 </p></dd>
 <dt>SQLITE_TOOBIG</dt>
-<dd><p>SQLite cannot store more than about 64K of data in a single row
-of a single table.  If you attempt to store more than 64K in a single
-row, this is the return code you get.
+<dd><p>SQLite will not store more than about 1 megabyte of data in a single
+row of a single table.  If you attempt to store more than 1 megabyte
+in a single row, this is the return code you get.
 </p></dd>
 <dt>SQLITE_CONSTRAINT</dt>
 <dd><p>This constant is returned if the SQL statement would have violated
 a database constraint.
 </p></dd>
+<dt>SQLITE_MISMATCH</dt>
+<dd><p>This error occurs when there is an attempt to insert non-integer
+data into a column labeled INTEGER PRIMARY KEY.  For most columns, SQLite
+ignores the data type and allows any kind of data to be stored.  But
+an INTEGER PRIMARY KEY column is only allowed to store integer data.
+</p></dd>
+<dt>SQLITE_MISUSE</dt>
+<dd><p>This error might occur if one or more of the SQLite API routines
+is used incorrectly.  Examples of incorrect usage include calling
+<b>sqlite_exec()</b> after the database has been closed using
+<b>sqlite_close()</b> or calling <b>sqlite_exec()</b> with the same
+database pointer simultaneously from two separate threads.
+</p></dd>
 </dl>
 </blockquote>
 
+<h2>The Extended API</h2>
+
+<p>Only the three core routines shown above are required to use
+SQLite.  But there are many other functions that provide 
+useful interfaces.  These extended routines are as follows:
+</p>
+
+<blockquote><pre>
+int sqlite_last_insert_rowid(sqlite*);
+
+int sqlite_changes(sqlite*);
+
+int sqlite_get_table(
+  sqlite*,
+  char *sql,
+  char ***result,
+  int *nrow,
+  int *ncolumn,
+  char **errmsg
+);
+
+void sqlite_free_table(char**);
+
+void sqlite_interrupt(sqlite*);
+
+int sqlite_complete(const char *sql);
+
+void sqlite_busy_handler(sqlite*, int (*)(void*,const char*,int), void*);
+
+void sqlite_busy_timeout(sqlite*, int ms);
+
+const char sqlite_version[];
+
+const char sqlite_encoding[];
+
+int sqlite_exec_printf(
+  sqlite*,
+  char *sql,
+  int (*)(void*,int,char**,char**),
+  void*,
+  char **errmsg,
+  ...
+);
+
+int sqlite_exec_vprintf(
+  sqlite*,
+  char *sql,
+  int (*)(void*,int,char**,char**),
+  void*,
+  char **errmsg,
+  va_list
+);
+
+int sqlite_get_table_printf(
+  sqlite*,
+  char *sql,
+  char ***result,
+  int *nrow,
+  int *ncolumn,
+  char **errmsg,
+  ...
+);
+
+int sqlite_get_table_vprintf(
+  sqlite*,
+  char *sql,
+  char ***result,
+  int *nrow,
+  int *ncolumn,
+  char **errmsg,
+  va_list
+);
+
+char *sqlite_mprintf(const char *zFormat, ...);
+
+char *sqlite_vmprintf(const char *zFormat, va_list);
+
+void sqlite_freemem(char*);
+
+</pre></blockquote>
+
+<p>All of the above definitions are included in the "sqlite.h"
+header file that comes in the source tree.</p>
+
+<h2>The ROWID of the most recent insert</h2>
+
+<p>Every row of an SQLite table has a unique integer key.  If the
+table has a column labeled INTEGER PRIMARY KEY, then that column
+serves as the key.  If there is no INTEGER PRIMARY KEY column then
+the key is a unique integer.  The key for a row can be accessed in
+a SELECT statement or used in a WHERE or ORDER BY clause using any
+of the names "ROWID", "OID", or "_ROWID_".</p>
+
+<p>When you do an insert into a table that does not have an INTEGER PRIMARY
+KEY column, or if the table does have an INTEGER PRIMARY KEY but the value
+for that column is not specified in the VALUES clause of the insert, then
+the key is automatically generated.  You can find the value of the key
+for the most recent INSERT statement using the
+<b>sqlite_last_insert_rowid()</b> API function.</p>
+
+<h2>The number of rows that changed</h2>
+
+<p>The <b>sqlite_changes()</b> API function returns the number of rows
+that were inserted, deleted, or modified during the most recent
+<b>sqlite_exec()</b> call.  The number reported includes any changes
+that were later undone by a ROLLBACK or ABORT.  But rows that are
+deleted because of a DROP TABLE are <em>not</em> counted.</p>
+
+<p>SQLite implements the command "<b>DELETE FROM table</b>" (without
+a WHERE clause) by dropping the table then recreating it.  
+This is much faster than deleting the elements of the table individually.
+But it also means that the value returned from <b>sqlite_changes()</b>
+will be zero regardless of the number of elements that were originally
+in the table.  If an accurate count of the number of elements deleted
+is necessary, use "<b>DELETE FROM table WHERE 1</b>" instead.</p>
+
 <h2>Querying without using a callback function</h2>
 
 <p>The <b>sqlite_get_table()</b> function is a wrapper around
 <b>sqlite_exec()</b> that collects all the information from successive
-callbacks and write it into memory obtained from malloc().  This
+callbacks and writes it into memory obtained from malloc().  This
 is a convenience function that allows the application to get the
 entire result of a database query with a single function call.</p>
 
@@ -344,7 +433,7 @@ entire result of a database query with a single function call.</p>
 to strings.  There is one element in this array for each column of
 each row in the result.  NULL results are represented by a NULL
 pointer. In addition to the regular data, there is an added row at the 
-beginning of the array that contains the names of each column of the
+beginning of the array that contains the name of each column of the
 result.</p>
 
 <p>As an example, consider the following query:</p>
@@ -375,10 +464,46 @@ result[8] = "zadok"
 <p>Notice that the "host" value for the "dummy" record is NULL so
 the result[] array contains a NULL pointer at that slot.</p>
 
+<p>If the result set of a query is empty, then by default
+<b>sqlite_get_table()</b> will set nrow to 0 and leave its
+result parameter is set to NULL.  But if the EMPTY_RESULT_CALLBACKS
+pragma is ON then the result parameter is initialized to the names
+of the columns only.  For example, consider this query which has
+an empty result set:</p>
+
+<blockquote>
+SELECT employee_name, login, host FROM users WHERE employee_name IS NULL;
+</blockquote>
+
+<p>
+The default behavior gives this results:
+</p>
+
+<blockquote>
+nrow = 0<br>
+ncolumn = 0<br>
+result = 0<br>
+</blockquote>
+
+<p>
+But if the EMPTY_RESULT_CALLBACKS pragma is ON, then the following
+is returned:
+</p>
+
+<blockquote>
+nrow = 0<br>
+ncolumn = 3<br>
+result[0] = "employee_name"<br>
+result[1] = "login"<br>
+result[2] = "host"<br>
+</blockquote>
+
 <p>Memory to hold the information returned by <b>sqlite_get_table()</b>
 is obtained from malloc().  But the calling function should not try
 to free this information directly.  Instead, pass the complete table
-to <b>sqlite_free_table()</b> when the table is no longer needed.</p>
+to <b>sqlite_free_table()</b> when the table is no longer needed.
+It is safe to call <b>sqlite_free_table()</b> with a NULL pointer such
+as would be returned if the result set is empty.</p>
 
 <p>The <b>sqlite_get_table()</b> routine returns the same integer
 result code as <b>sqlite_exec()</b>.</p>
@@ -386,7 +511,7 @@ result code as <b>sqlite_exec()</b>.</p>
 <h2>Interrupting an SQLite operation</h2>
 
 <p>The <b>sqlite_interrupt()</b> function can be called from a
-different thread or from a signal handler to the current database
+different thread or from a signal handler to cause the current database
 operation to exit at its first opportunity.  When this happens,
 the <b>sqlite_exec()</b> routine (or the equivalent) that started
 the database operation will return SQLITE_INTERRUPT.</p>
@@ -440,14 +565,14 @@ be changed at run-time.  This is a compile-time option only.  The
 <b>sqlite_encoding</b> character string just tells you how the library
 was compiled.</p>
 
-<h2>Changing the libraries response to locked files</h2>
+<h2>Changing the library's response to locked files</h2>
 
 <p>The <b>sqlite_busy_handler()</b> procedure can be used to register
 a busy callback with an open SQLite database.  The busy callback will
-be invoked whenever SQLite tries to open a locked that is locked.
+be invoked whenever SQLite tries to access a database that is locked.
 The callback will typically do some other useful work, or perhaps sleep,
 in order to give the lock a chance to clear.  If the callback returns
-non-zero, then SQLite tries again to open the database and the cycle
+non-zero, then SQLite tries again to access the database and the cycle
 repeats.  If the callback returns zero, then SQLite aborts the current
 operation and returns SQLITE_BUSY.</p>
 
@@ -458,8 +583,8 @@ the first argument to the busy callback.  When SQLite invokes the
 busy callback, it sends it three arguments:  the generic pointer
 that was passed in as the third argument to <b>sqlite_busy_handler</b>,
 the name of the database table or index that the library is trying
-to open, and the number of times that the library has attempted to
-open the database table or index.</p>
+to access, and the number of times that the library has attempted to
+access the database table or index.</p>
 
 <p>For the common case where we want the busy callback to sleep,
 the SQLite library provides a convenience routine <b>sqlite_busy_timeout()</b>.
@@ -494,19 +619,23 @@ additional arguments are attached to the end of the function call.</p>
 functions instead of <b>sprintf()</b>.  First of all, with the
 SQLite printf routines, there is never a danger of overflowing a
 static buffer as there is with <b>sprintf()</b>.  The SQLite
-printf routines automatically allocate (and later free)
+printf routines automatically allocate (and later frees)
 as much memory as is 
 necessary to hold the SQL statements generated.</p>
 
 <p>The second advantage the SQLite printf routines have over
-<b>sprintf()</b> is a new formatting option specifically designed
+<b>sprintf()</b> are two new formatting options specifically designed
 to support string literals in SQL.  Within the format string,
 the %q formatting option works very much like %s in that it
 reads a null-terminated string from the argument list and inserts
 it into the result.  But %q translates the inserted string by
 making two copies of every single-quote (') character in the
 substituted string.  This has the effect of escaping the end-of-string
-meaning of single-quote within a string literal.
+meaning of single-quote within a string literal. The %Q formatting
+option works similar; it translates the single-quotes like %q and
+additionally encloses the resulting string in single-quotes.
+If the argument for the %Q formatting options is a NULL pointer,
+the resulting string is NULL without single quotes.
 </p>
 
 <p>Consider an example.  Suppose you are trying to insert a string
@@ -549,6 +678,151 @@ single-quote character ('), it is always a good idea to use the
 SQLite printf routines and the %q formatting option instead of <b>sprintf</b>.
 </p>
 
+<p>If the %Q formatting option is used instead of %q, like this:</p>
+
+<blockquote><pre>
+sqlite_exec_printf(db,
+  "INSERT INTO table1 VALUES(%Q)",
+  0, 0, 0, zString);
+</pre></blockquote>
+
+<p>Then the generated SQL will look like the following:</p>
+
+<blockquote><pre>
+INSERT INTO table1 VALUES('Hi y''all')
+</pre></blockquote>
+
+<p>If the value of the zString variable is NULL, the generated SQL
+will look like the following:</p>
+
+<blockquote><pre>
+INSERT INTO table1 VALUES(NULL)
+</pre></blockquote>
+
+<p>All of the _printf() routines above are built around the following
+two functions:</p>
+
+<blockquote><pre>
+char *sqlite_mprintf(const char *zFormat, ...);
+char *sqlite_vmprintf(const char *zFormat, va_list);
+</pre></blockquote>
+
+<p>The <b>sqlite_mprintf()</b> routine works like the the standard library
+<b>sprintf()</b> except that it writes its results into memory obtained
+from malloc() and returns a pointer to the malloced buffer.  
+<b>sqlite_mprintf()</b> also understands the %q and %Q extensions described
+above.  The <b>sqlite_vmprintf()</b> is a varargs version of the same
+routine.  The string pointer that these routines return should be freed
+by passing it to <b>sqlite_freemem()</b>.
+</p>
+
+<a name="cfunc">
+<h2>Adding New SQL Functions</h2>
+
+<p>Beginning with version 2.4.0, SQLite allows the SQL language to be
+extended with new functions implemented as C code.  The following interface
+is used:
+</p>
+
+<blockquote><pre>
+typedef struct sqlite_func sqlite_func;
+
+int sqlite_create_function(
+  sqlite *db,
+  const char *zName,
+  int nArg,
+  void (*xFunc)(sqlite_func*,int,const char**),
+  void *pUserData
+);
+int sqlite_create_aggregate(
+  sqlite *db,
+  const char *zName,
+  int nArg,
+  void (*xStep)(sqlite_func*,int,const char**),
+  void (*xFinalize)(sqlite_func*),
+  void *pUserData
+);
+
+char *sqlite_set_result_string(sqlite_func*,const char*,int);
+void sqlite_set_result_int(sqlite_func*,int);
+void sqlite_set_result_double(sqlite_func*,double);
+void sqlite_set_result_error(sqlite_func*,const char*,int);
+
+void *sqlite_user_data(sqlite_func*);
+void *sqlite_aggregate_context(sqlite_func*, int nBytes);
+int sqlite_aggregate_count(sqlite_func*);
+</pre></blockquote>
+
+<p>
+The <b>sqlite_create_function()</b> interface is used to create 
+regular functions and <b>sqlite_create_aggregate()</b> is used to
+create new aggregate functions.  In both cases, the <b>db</b>
+parameter is an open SQLite database on which the functions should
+be registered, <b>zName</b> is the name of the new function,
+<b>nArg</b> is the number of arguments, and <b>pUserData</b> is
+a pointer which is passed through unchanged to the C implementation
+of the function.  Both routines return 0 on success and non-zero
+if there are any errors.
+</p>
+
+<p>
+The length of a function name may not exceed 255 characters.
+Any attempt to create a function whose name exceeds 255 characters
+in length will result in an error.
+</p>
+
+<p>
+For regular functions, the <b>xFunc</b> callback is invoked once
+for each function call.  The implementation of xFunc should call
+one of the <b>sqlite_set_result_...</b> interfaces to return its
+result.  The <b>sqlite_user_data()</b> routine can be used to
+retrieve the <b>pUserData</b> pointer that was passed in when the
+function was registered.
+</p>
+
+<p>
+For aggregate functions, the <b>xStep</b> callback is invoked once
+for each row in the result and then <b>xFinalize</b> is invoked at the
+end to compute a final answer.  The xStep routine can use the
+<b>sqlite_aggregate_context()</b> interface to allocate memory that
+will be unique to that particular instance of the SQL function.
+This memory will be automatically deleted after xFinalize is called.
+The <b>sqlite_aggregate_count()</b> routine can be used to find out
+how many rows of data were passed to the aggregate.  The xFinalize
+callback should invoke one of the <b>sqlite_set_result_...</b>
+interfaces to set the final result of the aggregate.
+</p>
+
+<p>
+SQLite now implements all of its built-in functions using this
+interface.  For additional information and examples on how to create
+new SQL functions, review the SQLite source code in the file
+<b>func.c</b>.
+</p>
+
+<h2>Multi-Threading And SQLite</h2>
+
+<p>
+If SQLite is compiled with the THREADSAFE preprocessor macro set to 1,
+then it is safe to use SQLite from two or more threads of the same process
+at the same time.  But each thread should have its own <b>sqlite*</b>
+pointer returned from <b>sqlite_open()</b>.  It is never safe for two
+or more threads to access the same <b>sqlite*</b> pointer at the same time.
+</p>
+
+<p>
+In precompiled SQLite libraries available on the website, the Unix
+versions are compiled with THREADSAFE turned off but the windows
+versions are compiled with THREADSAFE turned on.  If you need something
+different that this you will have to recompile.
+</p>
+
+<p>
+Under Unix, an <b>sqlite*</b> pointer should not be carried across a
+<b>fork()</b> system call into the child process.  The child process
+should open its own copy of the database after the <b>fork()</b>.
+</p>
+
 <h2>Usage Examples</h2>
 
 <p>For examples of how the SQLite C/C++ interface can be used,
