@@ -1,7 +1,7 @@
 #
 # Run this Tcl script to generate the vdbe.html file.
 #
-set rcsid {$Id: vdbe.tcl,v 1.7 2001/09/28 23:11:24 drh Exp $}
+set rcsid {$Id: vdbe.tcl,v 1.9 2001/11/24 13:23:05 drh Exp $}
 
 puts {<html>
 <head>
@@ -12,7 +12,7 @@ puts {<html>
 The Virtual Database Engine of SQLite
 </h1>}
 puts "<p align=center>
-(This page was last modified on [lrange $rcsid 3 4] GMT)
+(This page was last modified on [lrange $rcsid 3 4] UTC)
 </p>"
 
 puts {
@@ -1616,7 +1616,7 @@ difficulty understanding the rest.</p>
 
 <p>If you find errors in either the documentation or the code,
 feel free to fix them and/or contact the author at
-<a href="drh@hwaci.com">drh@hwaci.com</a>.  Your bug fixes or
+<a href="mailto:drh@hwaci.com">drh@hwaci.com</a>.  Your bug fixes or
 suggestions are always welcomed.</p>
 }
 
